commit 5fe6a9e993a9b025e5ec46550bf8831782190e32
Merge: c475b39 77d8adf
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 16:35:41 2026 +0700

    Merge pull request #17 from alexeev-prog/refactor/typing-and-codestyle

commit 77d8adf944a14fb97f30b1e96cf598906eab9363
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 16:34:52 2026 +0700

    fix linter errors

commit 4cc42c9c0f5ca44eee69fa52b100c0588d6d46dd
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 16:30:05 2026 +0700

    update codestyle and typing annotations

commit c475b39fd33bfd9cf40d81de80ed11f55f808f60
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 16:23:59 2026 +0700

    update docs & changelog.md

commit 67a9f152603e98d1c315fc37db1c19f4a0851a90
Merge: dc28de7 5ef1d68
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 16:23:23 2026 +0700

    Merge pull request #16 from alexeev-prog/refactor+docs/refactor-core

commit 5ef1d68c29f93c4f52d2e826e5a1d53ab4f69c10
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 16:20:48 2026 +0700

    refactor: core-modules (dns_lookup, utils, network_base) and improve docs (add more documentation)

commit dc28de700936bcbc91b8ca78569a88511d344463
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 01:40:40 2026 +0700

    Update 2026-03-07 01:40:40

commit 0d1d4535570b01eb54054857f9e44aa1296b6c6a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 01:37:49 2026 +0700

    refactor: improve typing annotations

commit 103ad4b9975a4885b9969976bc30c54d7d9049c0
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 01:35:48 2026 +0700

    update changelog

commit bcd6d9ef9175c6c09a7a6978f8e8cfe6fdf93420
Merge: e206893 f297d91
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 01:35:22 2026 +0700

    Merge pull request #15 from alexeev-prog/feature/dns-monitoring

commit f297d91437e75e3bba4fd190f6187b417f1f169d
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Mar 7 01:33:38 2026 +0700

    feat: add monitor and monitor-report commands

commit e206893ea04a6c19255479fa6192bdf5bff576f4
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 23:41:48 2026 +0700

    docs: update readme and improve docs

commit 3aae4d42a0069781e49ae3c60fd61b43f863e9c6
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 23:24:55 2026 +0700

    update readme and versions

commit 033617d94b2976147ad3229b32f562d09f043ed8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 23:22:57 2026 +0700

    upload new version: 0.1.5

commit 680d715f4736f65bc442bf0469eeaba7ecb7ffc6
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 23:19:02 2026 +0700

    update changelog

commit ac6fdc9dd3f1e91299d96fc39adee918a0e53b47
Merge: f06f741 c43a99a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 23:18:27 2026 +0700

    Merge pull request #14 from alexeev-prog/refactor/typing-improvements

commit c43a99a1cf153c99e40786af28992bee862cd55d
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 23:17:35 2026 +0700

    fix lint error

commit ee34a9883477ecc7cfa7c763f919f8e1705c4a70
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 23:15:36 2026 +0700

    improve typing annotations in code

commit f06f741c4d5d1cd4f7d3e64173c1a878fec761a1
Merge: 5eb2806 35e7ec2
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 16:59:47 2026 +0700

    Merge pull request #13 from alexeev-prog/refactor/code-api-improvements

commit 35e7ec20431f96a3fcc6e6d014a7e392e09a293a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 16:58:58 2026 +0700

    fix linter errors

commit fc0ffc9af0bc884b6ef38ab0e4e8456d1560c194
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 16:57:44 2026 +0700

    fix lint errors

commit 8df04afeea0c21d3e03ee4351fb243c0b94cb4ca
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 16:53:05 2026 +0700

    fix lint errors

commit b49de8ac513ca68bd8d156f55fab8277dcb6b8d0
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 16:51:43 2026 +0700

    fix lint errors

commit 63caf0d1d6fde6022cafb111cc80ebf590ca5ebc
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 16:46:34 2026 +0700

    refactor: update code api, improve code quality

commit 5eb28060375709a805e33f2467b7d5fa1392d4a8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 15:50:16 2026 +0700

    update docs config

commit 9e116bee346eb7a4893fe6a0fc898052e3412ff9
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 15:42:35 2026 +0700

    update docs templates

commit 0f5e61f3005041ac7754a794bf39729a5e08a75a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 15:37:47 2026 +0700

    update docs templates

commit 82c0c81ce8c9e1da52aeff60c8053dc5bf14d09b
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 15:34:33 2026 +0700

    update docs templates

commit 1083449f88fbf0a164f6f945112a33910eba07ca
Merge: 13c8dbd 0b1763b
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 15:31:13 2026 +0700

    Merge pull request #12 from alexeev-prog/dependabot/github_actions/actions/upload-pages-artifact-4

commit 13c8dbdfa64cb93464d29c474f6be94895353cd2
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 15:29:18 2026 +0700

    update docs templates

commit b1b078990f10512ddc4bef8de3c2d9f886f5ed1d
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 08:50:36 2026 +0700

    update docs templates

commit 2044b89526ea17f9448bc43a3106cfb1b6ef73c8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 08:44:56 2026 +0700

    fix docs workflow error

commit 7a89167b6b7ebfa3d7145ab3107785ca4f924552
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 08:40:36 2026 +0700

    update docs (versioning and context7 widget)

commit 0b1763b6ae0786a171a0fc77ed46bf7024a65cec
Author: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
Date:   Thu Mar 5 18:38:40 2026 +0000

    Bump actions/upload-pages-artifact from 3 to 4
    
    Bumps [actions/upload-pages-artifact](https://github.com/actions/upload-pages-artifact) from 3 to 4.
    - [Release notes](https://github.com/actions/upload-pages-artifact/releases)
    - [Commits](https://github.com/actions/upload-pages-artifact/compare/v3...v4)
    
    ---
    updated-dependencies:
    - dependency-name: actions/upload-pages-artifact
      dependency-version: '4'
      dependency-type: direct:production
      update-type: version-update:semver-major
    ...
    
    Signed-off-by: dependabot[bot] <support@github.com>

commit 396e873aaf98d07a8710019b0554495834cf123e
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 00:07:19 2026 +0700

    remove pylint workflow

commit 4cf78c09dab6bbbd453949af9c15ae5ca1f9f056
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 00:06:52 2026 +0700

    Create pylint.yml

commit b93f8d0393d9354cf118cb1d7f43ac6b841d3de5
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 00:03:06 2026 +0700

    update

commit e193f1f1288387e81cdb6b64e4186cfdc483e783
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Mar 6 00:00:03 2026 +0700

    update docs

commit 868ba82e37076f172552ea8f45f77038faf2474a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Thu Mar 5 23:48:26 2026 +0700

    update docs

commit 467f71601c43be408c4b9178d26939529eb3e2dc
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 18:26:18 2026 +0700

    Update 2026-03-04 18:26:18

commit 658b99c463560a7728cb6826d678c05c6dc6073c
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 18:25:43 2026 +0700

    update docs

commit 0000e1fa7f57b50233aa62702b5dff04eec01b65
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 18:22:07 2026 +0700

    update docs

commit 73bad5f352c399eb8f28fce620fd45874aa1ca9f
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 18:20:10 2026 +0700

    update docs and publish release

commit 2124419608551f030d05bb46b931d3c5180e9da9
Merge: 8c151e0 7afe709
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 18:02:21 2026 +0700

    Merge pull request #11 from alexeev-prog/feature/arp-command-group

commit 7afe709d503ba9938bbf8db13cfc41963d540825
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 18:00:53 2026 +0700

    add arp spoofing, monitor and cache commands

commit 8c151e0560c51f7211f21ef111fa66f0c9c88dde
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 17:30:18 2026 +0700

    update latest-docs

commit 60bc7b0d138a331c483f6d4fe7bdb2c3519d153e
Merge: bf29a83 573fbe3
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 17:25:09 2026 +0700

    Merge pull request #10 from alexeev-prog/feature/more-network-base-commands

commit 573fbe3d3bfb170bf82c86640c38436823264df5
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 17:17:40 2026 +0700

    add http-ping, whois, connections, traceroute, route commands and update docs&readme

commit bf29a835523cc5d91dd7a2850cdef18ddce97330
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 16:00:51 2026 +0700

    update docs (finally

commit cd0362ba1b5ca4994d24d9607b252985a9e706bf
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:54:32 2026 +0700

    update docs (fix)

commit 6029c8a593b47ae1a18e57ab4b87c4811bd642e2
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:50:47 2026 +0700

    update docs (fix)

commit 40a6f27993ee48560177c9c0ae132470e85682a7
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:45:26 2026 +0700

    update docs (fix)

commit e10ed0e545f91863aa76695ae2e5fb4ffd617d18
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:39:03 2026 +0700

    update docs (fix)

commit 8757b2ed06ad73ea9539e7dd2150c1b10cf753b3
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:31:12 2026 +0700

    update docs (fix)

commit 437618e209d917215ad895af8e14a6e5a4ed32ee
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:26:15 2026 +0700

    update docs (fix)

commit 1cdcc3562f12f51d1175e08e0544ce83b29dca46
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:23:22 2026 +0700

    update docs (fix)

commit b81e67e2c397880ab7bcbdf8bb1a0c703a4101c2
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:21:32 2026 +0700

    update docs (fix)

commit 82611b59e5fd553ef186aee4b1697a20001cd1e8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 15:18:58 2026 +0700

    update docs (fix)

commit f5d855c58b855ce31b9827e2dbaa71148e2b26ac
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:58:10 2026 +0700

    update docs (fix)

commit 792f003a3eb45b0ed76ff3b2a917be030d86c268
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:49:56 2026 +0700

    update docs (fix)

commit 86659ce4b21779544af593b32bc2c805f1a2d8ea
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:47:04 2026 +0700

    update docs (fix)

commit c270b1d650d1ca652755f36954921d8c66e4e8b5
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:37:48 2026 +0700

    update docs (fix)

commit 3309157d26184d12d50f3b130749bdf086d66304
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:36:11 2026 +0700

    update docs (fix)

commit 9b3ca77695966f06ceb0d8cae951621013be32bd
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:32:44 2026 +0700

    update docs (fix)

commit 372c65a0be7b46d7395c537d1c0b91a212245ac6
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:31:09 2026 +0700

    update docs (fix)

commit 764a9b07ba50d2e09c3143db0bd49390020ceffb
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:27:56 2026 +0700

    update docs (fix)

commit 60f7d1d1fe6b8d0cd6def370e991637a9f70644c
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:13:21 2026 +0700

    update docs (fix)

commit 4976deee9857a1d3545999edb80d709048be5417
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:03:15 2026 +0700

    update docs (fix)

commit 214f0a70448510c0dc1972d2d4c82b268622cc54
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 14:00:58 2026 +0700

    update docs (fix)

commit 7dfa963ead3e27386549af2f245907e88af0adc5
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 13:54:26 2026 +0700

    update docs (fix)

commit 65fda52a35ad57afec64be1fa9d08ce99dfe7b33
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 13:51:15 2026 +0700

    update docs (fix)

commit a8da6e08eef4c76ab75af02cd257dfa4678f0cea
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:52:28 2026 +0700

    update docs (fix)

commit 3619641fb0b134ece5b4baee5dcdd51bac3a8745
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:50:20 2026 +0700

    Update 2026-03-04 07:16:40

commit 6542c3c554be2d66eb5f67fb7fc72cb477521d14
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:47:13 2026 +0700

    update docs (fix)

commit 0d1a070958610911e53f6723c918a30ea0dc7d4f
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:44:08 2026 +0700

    update docs (fix)

commit c2e27945ffe5120ee420b43bdb7ee294267e18ac
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:40:19 2026 +0700

    update docs

commit 01f827c89cf0ab2d0488a1d5859560ee21042fa2
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:35:33 2026 +0700

    Update 2026-03-04 07:16:40

commit 8e4725890c2c2ee651e30517ef57191cc6fb1c87
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:31:53 2026 +0700

    update docs

commit 2b9dce76b71ddc398874a21a26bc565a92acd38e
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:29:03 2026 +0700

    remove index.html

commit 915ff318063533b8abf9a72aacd6f530f89d34e1
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:24:11 2026 +0700

    updatw docs workflow (fix)

commit 3522855786e28eae7b5390cf7ccc1faf05aa174e
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 07:18:15 2026 +0700

    updatw changelog

commit 44d27db58b9d26bf4ca13a18c941431dbdfd202b
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 00:19:27 2026 +0700

    update docs workflows

commit bd06f56ce2b42f4ecc432ef5473eeb97ac291f43
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 00:18:43 2026 +0700

    update docs workflows

commit b9ba8802494836161f18474bed05c1ab129b40b0
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 00:16:59 2026 +0700

    update docs workflows

commit 49813a317c530c5224e5668940c260d1c43f49c6
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 00:14:41 2026 +0700

    update docs workflows

commit 95c29196a0d4acc9149d5185787ef6d795fda4f8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 00:12:55 2026 +0700

    update docs workflows

commit 2a395409d99aafb012ea5c100afbea9e577e1b6b
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 00:09:57 2026 +0700

    update docs workflows

commit 2e34ff1cc2a7ef64546bf0b2b34962bdfee10fc0
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Mar 4 00:04:34 2026 +0700

    update docs workflows

commit bc4b66b6bcda5d806140db909962c97f77d530f1
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:50:16 2026 +0700

    update docs workflows

commit cced4f38d0586e289d7c21052bda206fddfcf30e
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:47:28 2026 +0700

    update docs workflows

commit e56c87c184b22539ad882dc51f2825dd04bd275d
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:44:11 2026 +0700

    update docs workflows

commit 3aaf4b1894d4fc108e661146d053db5c4e6e6c0f
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:40:56 2026 +0700

    update docs workflows

commit 27645f9d3aa59dcf9e4c9a855196d89069cad733
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:37:54 2026 +0700

    update docs workflows

commit a03a9e9f29ad0bfbadb36a740e32754a799a041d
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:33:29 2026 +0700

    update (fix) docs workflows

commit ebcd0bcaca0b671fd0995476964cd6be1f136f6e
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:23:05 2026 +0700

    update (fix) docs workflows

commit 52201274fbff72df0b0d181c7cd89af65d3f26d0
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:19:29 2026 +0700

    update docs workflows

commit 5ebebf88e7be0c4d2a1afa345017cfc0f93d667b
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:16:38 2026 +0700

    update docs workflow

commit 7ce205e1851b739d0efaba61efee684439136a1a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:11:30 2026 +0700

    update docs-latest workflow

commit ee67f574fe928f92f8e53c58e4ff508504d3daba
Merge: 2a84be8 61980b1
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:09:48 2026 +0700

    Merge pull request #9 from alexeev-prog/docs/update

commit 61980b16c4b778b9ccb47c8fdc5fcc67b35eb6c8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 23:07:48 2026 +0700

    add docs-latest workflow, set docs-stable to publishing release, update docs structure

commit 2a84be8f420dc3ca40400b50458838125ade1ea3
Merge: 3ca3a0f e6a7f9a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 22:58:17 2026 +0700

    Merge pull request #8 from alexeev-prog/refactor/codestyle-improvements

commit e6a7f9a6d3cabf594bdde391d215bb05bc9cf461
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 22:53:52 2026 +0700

    update init files

commit 95cc802faf98e11d2e3cda67a6116e05c423db68
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Tue Mar 3 16:25:24 2026 +0700

    refactor:update codestyle, docstrings

commit 3ca3a0f1fe4533df33db7e45198f189660b4ea5c
Merge: 6effb8d ff854de
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Mon Mar 2 16:26:17 2026 +0700

    Merge pull request #7 from alexeev-prog/feature/port-scanner

commit ff854dec517f8680ffb6e2dc3b9ba70f6412e7bc
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Mon Mar 2 16:25:07 2026 +0700

    fix test error: network_base.service_on_port unknown->Unknown

commit 8f903e9c533bc249e30599b42b8784d60b8930fe
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Mon Mar 2 16:21:24 2026 +0700

    add port-scanner command to network-base

commit 6effb8d2672063c98d0c2c9625b1fed6c1fc2279
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Feb 28 22:03:54 2026 +0700

    update docs

commit 17c5d8c93d1cee3a9e6095bc3b00e789038f6547
Merge: 4d6f67d c028d3c
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Thu Feb 26 15:12:04 2026 +0700

    Merge pull request #6 from alexeev-prog/refactor/codestyle-improvements

commit c028d3ceede175a4c50d81b2dc79dfa2904c785c
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Thu Feb 26 15:09:00 2026 +0700

    update docstrings, codestyle

commit 4d6f67d81bee6850e05190c0d7d2b83fb963d378
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Feb 25 21:07:31 2026 +0700

    update docs

commit a2466088ff4ff968923cb0010fd7b5c053d25653
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Feb 25 21:02:28 2026 +0700

    update readme and upload 0.1.3

commit cc6e037af2839aa3f303fcb36c59988f087e3372
Merge: e68efbb ea14df8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Feb 25 20:57:40 2026 +0700

    Merge pull request #5 from alexeev-prog/feature/extended-dns-commands

commit ea14df8d7b78be598450cbea55b23988eb738294
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Feb 25 20:56:13 2026 +0700

    update typing

commit 2fe05871e0b8f739ac50b3f9ec3fcd770af92731
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Feb 25 20:55:40 2026 +0700

    update docstring

commit 921d51276b2e678effefcbf7ff5bec9aade724c8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Wed Feb 25 20:49:56 2026 +0700

    update dns-commands and dns lookup, utils

commit e68efbb29cfc29741b5aacdd147a5bda03a74c71
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Mon Feb 23 22:07:17 2026 +0700

    update license

commit d0b39089a8f9a16748dd47a69bd4ba8bad0e5960
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Mon Feb 23 22:02:22 2026 +0700

    update docs and load 0.1.2

commit aad293a63ca5a6f65786a16023f86eca46cd673d
Merge: 49a12ef 926a5ea
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Mon Feb 23 22:00:53 2026 +0700

    Merge pull request #4 from alexeev-prog/dns-lookup

commit 926a5eae9af473b0048faa45c1da51707fe9266d
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Mon Feb 23 21:54:33 2026 +0700

    create `dns` command group; split architecture cli.py -> commands modules group

commit 49a12efeadbe8307f9faca010f63e0944c2ac2f2
Merge: eeaae18 64afd30
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sun Feb 22 13:32:48 2026 +0700

    Merge pull request #3 from alexeev-prog/network-base-improvements

commit 64afd30a00427af05fcdf48d07b1abd5dd4809c8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sun Feb 22 13:30:13 2026 +0700

    add help for commands

commit 030143040cf4289f026c8c5893114132c0868698
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sun Feb 22 00:51:51 2026 +0700

    add commands for get location by ip and improve network-params

commit eeaae18a16077d09efe52ceef289e0c6603f7a49
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Feb 21 00:10:01 2026 +0700

    add public ip to network params; release 0.1.1

commit ca4ce9f8722613118da634be131cf7fdd9fca552
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Feb 21 00:01:11 2026 +0700

    update docs

commit 8c1cd9fc7d8d5dea8b30d84ebf5ccff9da261499
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Sat Feb 21 00:01:00 2026 +0700

    update typing

commit 482406b35941b17f39d10bb3a6e50d75eea442a9
Merge: ac27677 3c482ce
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:58:48 2026 +0700

    Merge pull request #2 from alexeev-prog/dependabot/github_actions/actions/setup-python-6

commit 3c482cea22358e55c6866d9f068237a71341b8de
Merge: ab14def ac27677
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:58:39 2026 +0700

    Merge branch 'main' into dependabot/github_actions/actions/setup-python-6

commit ac276777a56a1744771d1bf9d130660cd7b2196a
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:58:19 2026 +0700

    update docs

commit 75df49a4cf5c33641d9fbd73ffc609e1b2636dd8
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:57:27 2026 +0700

    update docs

commit 79d5e1e3b1a8b7fc1e0ac09287ad47ff1c25ee0e
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:56:32 2026 +0700

    update readme

commit cefba08c660df0085bd752a4284b359873543f44
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:54:23 2026 +0700

    improve CLI App UX/UI and publish package; update readme

commit 113a20855d679499c361fd3b56810c6260be2ede
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 23:23:51 2026 +0700

    add get-network-params and ping-address commands

commit c0c74257ad27c31bef2522a541db32834c9e0444
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 17:49:24 2026 +0700

    update docs

commit dac508e4371aec6586445fd6fa547e373a53cabf
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Fri Feb 20 17:49:08 2026 +0700

    update tests

commit ab14defee8ebc8ba976ff67ddc1c46770b3a5ef2
Author: dependabot[bot] <49699333+dependabot[bot]@users.noreply.github.com>
Date:   Thu Feb 19 14:33:21 2026 +0000

    Bump actions/setup-python from 5 to 6
    
    Bumps [actions/setup-python](https://github.com/actions/setup-python) from 5 to 6.
    - [Release notes](https://github.com/actions/setup-python/releases)
    - [Commits](https://github.com/actions/setup-python/compare/v5...v6)
    
    ---
    updated-dependencies:
    - dependency-name: actions/setup-python
      dependency-version: '6'
      dependency-type: direct:production
      update-type: version-update:semver-major
    ...
    
    Signed-off-by: dependabot[bot] <support@github.com>

commit ef5dec057758497001394b010dcfe6c7def62f0c
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Thu Feb 19 21:32:38 2026 +0700

    create basic structure

commit d1462c8621dbffbf488084260507937dcedc6f39
Author: Alexeev Bronislav <alexeev.dev@mail.ru>
Date:   Thu Feb 19 17:57:08 2026 +0700

    Initial commit
